//webpack.config.js
const VueLoaderPlugin = require('vue-loader/lib/plugin');
const path = require('path');
const HTMLPlugin = require('html-webpack-plugin');
const webpack = require('webpack');

const isDev = process.env.NODE_ENV === '';

config = {
    target:'web',
    entry: path.join(__dirname,'src/index.js'), //调用Index.js作为入口文件
    output: { //打包完的js文件会在bundle.js中，这个文件待会会自动生成的
        filename: 'bundle.js',
        path: path.join(__dirname,'dist') //用来存放bundle.js文件的地址，自己定义
    },
    mode: 'development',//设置模式
    plugins: [
        new webpack.DefinePlugin({
            'process.env':{
                NODE_ENV:isDev?'"development"':'"production"'
            }
        }),
        // make sure to include the plugin for the magic
        new VueLoaderPlugin(),
        new webpack.BannerPlugin('this is a test webpack application')
    ],
    module: {
        rules: [//配置webpack可以加载Js,css,图片文件
            {
                test: /.vue$/,
                loader: 'vue-loader'
            },
            {
                test: /.css$/,
                use:[
                    'style-loader',
                    'css-loader'
                ]
            },
            {
                test: /\.(gif|jpg|png|svg)$/,
                use: [{
                    loader: 'url-loader',
                    options: {
                        limit: 1024,
                        name:'[name].[ext]'
                    }
                }]
            },
            {
                test:/.styl$/,
                use: [
                    'style-loader',
                    'css-loader',
                    'stylus-loader'
                ]
            }
        ]

    }
};
if(isDev){
    config.devServer = {
        port:8000,
        host:'0.0.0.0',
        overlay:{
            errors:true
        },
        hot:true
    }
    config.plugins.push(
        new webpack.HotModuleReplacementPlugin(),
        new webpack.NoEmitOnErrorsPlugin()
    )
}
module.exports = config;